==> content_management-0.1.0.gem: app/controllers/content_management/admin/content_audiences_controller.rb <==
module ContentManagement
  class Admin::ContentAudiencesController < ContentManagementController
    # GET /content_audiences
    # GET /content_audiences.json
    def index
      @content_audiences = ContentAudience.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @content_audiences }
      end
    end

    # GET /content_audiences/1
    # GET /content_audiences/1.json
    def show
      @content_audience = ContentAudience.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @content_audience }
      end
    end

    # GET /content_audiences/new
    # GET /content_audiences/new.json
    def new
      @content_audience = ContentAudience.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @content_audience }
      end
    end

    # GET /content_audiences/1/edit
    def edit
      @content_audience = ContentAudience.find(params[:id])
    end

    # POST /content_audiences
    # POST /content_audiences.json
    def create
      @content_audience = ContentAudience.new(params[:content_audience])

      respond_to do |format|
        if @content_audience.save
          format.html { redirect_to @content_audience, :notice => 'Content audience was successfully created.' }
          format.json { render :json => @content_audience, :status => :created, :location => @content_audience }
        else
          format.html { render :action => "new" }
          format.json { render :json => @content_audience.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /content_audiences/1
    # PUT /content_audiences/1.json
    def update
      @content_audience = ContentAudience.find(params[:id])

      respond_to do |format|
        if @content_audience.update_attributes(params[:content_audience])
          format.html { redirect_to @content_audience, :notice => 'Content audience was successfully updated.' }
          format.json { head :ok }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @content_audience.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /content_audiences/1
    # DELETE /content_audiences/1.json
    def destroy
      @content_audience = ContentAudience.find(params[:id])
      @content_audience.destroy

      respond_to do |format|
        format.html { redirect_to content_audiences_url }
        format.json { head :ok }
      end
    end
  end
end

==> content_management-0.1.4.gem: app/controllers/content_management/admin/content_audiences_controller.rb <==
module ContentManagement
  class Admin::ContentAudiencesController < ContentManagementController
    # GET /content_audiences
    # GET /content_audiences.json
    def index
      @content_audiences = ContentAudience.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @content_audiences }
      end
    end

    # GET /content_audiences/1
    # GET /content_audiences/1.json
    def show
      @content_audience = ContentAudience.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @content_audience }
      end
    end

    # GET /content_audiences/new
    # GET /content_audiences/new.json
    def new
      @content_audience = ContentAudience.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @content_audience }
      end
    end

    # GET /content_audiences/1/edit
    def edit
      @content_audience = ContentAudience.find(params[:id])
    end

    # POST /content_audiences
    # POST /content_audiences.json
    def create
      @content_audience = ContentAudience.new(params[:content_audience])

      respond_to do |format|
        if @content_audience.save
          format.html { redirect_to @content_audience, notice: 'Content audience was successfully created.' }
          format.json { render json: @content_audience, status: :created, location: @content_audience }
        else
          format.html { render action: 'new' }
          format.json { render json: @content_audience.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /content_audiences/1
    # PUT /content_audiences/1.json
    def update
      @content_audience = ContentAudience.find(params[:id])

      respond_to do |format|
        if @content_audience.update_attributes(params[:content_audience])
          format.html { redirect_to @content_audience, notice: 'Content audience was successfully updated.' }
          format.json { head :ok }
        else
          format.html { render action: 'edit' }
          format.json { render json: @content_audience.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /content_audiences/1
    # DELETE /content_audiences/1.json
    def destroy
      @content_audience = ContentAudience.find(params[:id])
      @content_audience.destroy

      respond_to do |format|
        format.html { redirect_to content_audiences_url }
        format.json { head :ok }
      end
    end
  end
end
